# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

# Data::Alias tends to be broken on new Perl releases
%global have_data_alias 0%{?fedora} < 25 && 0%{?rhel} < 8

Name:		perl-Data-Visitor
Version:	0.30
Release:	7.%{__distinit}%{__distvers}
Summary:	Visitor style traversal of Perl data structures
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Data-Visitor/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DO/DOY/Data-Visitor-%{version}.tar.gz
Patch0:		Data-Visitor-0.28-old-Test::More.patch
Patch1:		Data-Visitor-0.30-note.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Task::Weaken)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Class::Load)
BuildRequires:	perl(constant)
BuildRequires:	perl(Moose) >= 0.89
BuildRequires:	perl(namespace::clean) >= 0.19
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Sub::Name)
BuildRequires:	perl(Tie::ToObject) >= 0.01
# Optional Module Requirements
%if %{have_data_alias}
BuildRequires:	perl(Data::Alias)
%endif
# Test Suite
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Requires)
BuildRequires:	perl(Tie::RefHash)
# Release Tests
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%if %{have_data_alias}
Requires:	perl(Data::Alias)
%endif
Requires:	perl(Sub::Name)
Requires:	perl(Task::Weaken)

%description
This module is a simple visitor implementation for Perl values.

%prep
%setup -q -n Data-Visitor-%{version}

# We need to patch the test suite if we have an old Test::More version
%if %{old_test_more}
%patch0 -p1
%endif
%if %{older_test_more}
%patch1
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Data/
%{_mandir}/man3/Data::Visitor.3*
%{_mandir}/man3/Data::Visitor::Callback.3*

%changelog
* Thu May 19 2016 Paul Howarth <paul@city-fan.org> - 0.30-7
- Don't pull in Data::Alias in Perl 5.24+ as it's broken there
  (CPAN RT#112289)
- BR: perl-generators where available
- Simplify find command using -delete

* Thu Oct 22 2015 Paul Howarth <paul@city-fan.org> - 0.30-6
- Reinstate unconditional use of Data::Alias

* Tue Jun 30 2015 Paul Howarth <paul@city-fan.org> - 0.30-5
- Don't pull in Data::Alias in Perl 5.22+ as it's broken there
  (CPAN RT#100944)

* Tue Sep 16 2014 Paul Howarth <paul@city-fan.org> - 0.30-4
- Use %%license where possible

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 0.30-3
- Reinstate unconditional use of Data::Alias

* Wed Jul 24 2013 Paul Howarth <paul@city-fan.org> - 0.30-2
- Don't pull in Data::Alias in Perl 5.18+ as it's broken there
  (CPAN RT#78148, CPAN RT#85690)

* Tue Jun 25 2013 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30
  - The class callbacks to be run for an object are now chosen once, at the
    start of visiting that object (needed for consistency in the presence of
    hash order randomization)
- Classify buildreqs by usage
- Explicity require perl(Sub::Name) and perl(Task::Weaken)
- Run the release tests separately
- Add patch to support building with Test::More < 0.82

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 0.28-3
- BR: perl(File::Temp), perl(Scalar::Util), perl(Sub::Name) and
  perl(Tie::RefHash)
- Drop buildreqs for Perl core modules that are not dual-lived
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-5:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - %%defattr redundant since rpm 4.4

* Mon Feb 20 2012 Paul Howarth <paul@city-fan.org> - 0.28-2
- Import from Fedora

* Sun Feb 19 2012 Iain Arnell <iarnell@gmail.com> - 0.28-1
- Update to latest upstream version
- Clean up spec for modern rpmbuild
- Use perl_default_filter and DESTDIR
- Add LICENSE and README to docs

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.27-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jul 21 2011 Petr Sabata <contyk@redhat.com> - 0.27-5
- Perl mass rebuild

* Tue Jul 19 2011 Petr Sabata <contyk@redhat.com> - 0.27-4
- Perl mass rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.27-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 16 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.27-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue Jun  1 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.27-1
- Update

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.26-2
- Mass rebuild with perl-5.12.0

* Mon Jan 04 2010 Iain Arnell <iarnell@gmail.com> - 0.26-1
- Update to latest upstream version
- BR: perl(Moose), not perl(Any::Moose)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.25-3
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.25-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu May 21 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.25-1
- Auto-update to 0.25 (by cpan-spec-update 0.01)
- Altered br on perl(Any::Moose) (0 => 0.09)
- Altered br on perl(Tie::ToObject) (0 => 0.01)
- Altered br on perl(namespace::clean) (0 => 0.08)

* Tue May 05 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.24-1
- Update to 0.24

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.22-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 10 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.22-1
- Update to 0.22

* Wed Nov 12 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.21-1
- Update to 0.21

* Sat Sep 06 2008 Chris Weyl <cweyl@alumni.drew.edu> - 0.19-1
- Update to 0.19

* Wed Mar 05 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.09-2
- Rebuild for new perl

* Sun Oct 21 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.09-1
- Update to 0.09
- Update license tag: GPL -> GPL+
- Add t/ to doc
- Back to good old Makefile.PL; Build.PL seems to have gone away

* Thu May 03 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-2
- Bump

* Tue Apr 10 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-1
- Specfile autogenerated by cpanspec 1.70
